Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2081)

Unified Diff: chrome/browser/chromeos/gdata/gdata_file_system.h

Issue 9834091: gdata: Fix issue with copying hosted documents out from Docs folder. (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/gdata/gdata_file_system.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/gdata/gdata_file_system.h
===================================================================
--- chrome/browser/chromeos/gdata/gdata_file_system.h (revision 128807)
+++ chrome/browser/chromeos/gdata/gdata_file_system.h (working copy)
@@ -349,6 +349,10 @@
// <user_profile_dir>/GCache/v1/tmp/downloads/
virtual FilePath GetGDataTempDownloadFolderPath() const = 0;
+ // Returns the tmp documents sub-directory under gdata cache directory, i.e.
+ // <user_profile_dir>/GCache/v1/tmp/documents/
+ virtual FilePath GetGDataTempDocumentFolderPath() const = 0;
+
// Returns the pinned sub-directory under gdata cache directory, i.e.
// <user_profile_dir>/GCache/v1/pinned
virtual FilePath GetGDataCachePinnedDirectory() const = 0;
@@ -435,6 +439,7 @@
GDataFileProperties* properties) OVERRIDE;
virtual FilePath GetGDataCacheTmpDirectory() const OVERRIDE;
virtual FilePath GetGDataTempDownloadFolderPath() const OVERRIDE;
+ virtual FilePath GetGDataTempDocumentFolderPath() const OVERRIDE;
virtual FilePath GetGDataCachePinnedDirectory() const OVERRIDE;
virtual FilePath GetGDataCachePersistentDirectory() const OVERRIDE;
virtual FilePath GetCacheFilePath(
@@ -598,10 +603,11 @@
base::PlatformFileError *error);
// Creates a temporary JSON file representing a document with |edit_url|
// and |resource_id| on IO thread pool. Upon completion it will invoke
// |callback| with the path of the created temporary file on thread
// represented by |relay_proxy|.
static void CreateDocumentJsonFileOnIOThreadPool(
+ const FilePath& document_dir,
const GURL& edit_url,
const std::string& resource_id,
const GetFileCallback& callback,
@@ -598,10 +603,11 @@
base::PlatformFileError *error);
// Creates a temporary JSON file representing a document with |edit_url|
- // and |resource_id| on IO thread pool. Upon completion it will invoke
- // |callback| with the path of the created temporary file on thread
- // represented by |relay_proxy|.
+ // and |resource_id| under |document_dir| on IO thread pool. Upon completion
+ // it will invoke |callback| with the path of the created temporary file on
+ // thread represented by |relay_proxy|.
static void CreateDocumentJsonFileOnIOThreadPool(
« no previous file with comments | « no previous file | chrome/browser/chromeos/gdata/gdata_file_system.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698